@@ -27,7 +27,7 @@ from optparse import OptionParser
 
 tmpeggs = tempfile.mkdtemp()
 
-usage = '''\
+usage = """\
 [DESIRED PYTHON FOR BUILDOUT] bootstrap.py [options]
 
 Bootstraps a buildout-based project.
@@ -37,28 +37,40 @@ Python that you want bin/buildout to use.
 
 Note that by using --find-links to point to local resources, you can keep
 this script from going over the network.
-'''
+"""
 
 parser = OptionParser(usage=usage)
 parser.add_option("-v", "--version", help="use a specific zc.buildout version")
 
-parser.add_option("-t", "--accept-buildout-test-releases",
-                  dest='accept_buildout_test_releases',
-                  action="store_true", default=False,
-                  help=("Normally, if you do not specify a --version, the "
-                        "bootstrap script and buildout gets the newest "
-                        "*final* versions of zc.buildout and its recipes and "
-                        "extensions for you.  If you use this flag, "
-                        "bootstrap and buildout will get the newest releases "
-                        "even if they are alphas or betas."))
-parser.add_option("-c", "--config-file",
-                  help=("Specify the path to the buildout configuration "
-                        "file to be used."))
-parser.add_option("-f", "--find-links",
-                  help=("Specify a URL to search for buildout releases"))
-parser.add_option("--allow-site-packages",
-                  action="store_true", default=False,
-                  help=("Let bootstrap.py use existing site packages"))
+parser.add_option(
+    "-t",
+    "--accept-buildout-test-releases",
+    dest="accept_buildout_test_releases",
+    action="store_true",
+    default=False,
+    help=(
+        "Normally, if you do not specify a --version, the "
+        "bootstrap script and buildout gets the newest "
+        "*final* versions of zc.buildout and its recipes and "
+        "extensions for you.  If you use this flag, "
+        "bootstrap and buildout will get the newest releases "
+        "even if they are alphas or betas."
+    ),
+)
+parser.add_option(
+    "-c",
+    "--config-file",
+    help=("Specify the path to the buildout configuration " "file to be used."),
+)
+parser.add_option(
+    "-f", "--find-links", help=("Specify a URL to search for buildout releases")
+)
+parser.add_option(
+    "--allow-site-packages",
+    action="store_true",
+    default=False,
+    help=("Let bootstrap.py use existing site packages"),
+)
 
 
 options, args = parser.parse_args()
@@ -75,21 +87,22 @@ except ImportError:
     from urllib2 import urlopen
 
 ez = {}
-exec(urlopen('https://bootstrap.pypa.io/ez_setup.py').read(), ez)
+exec(urlopen("https://bootstrap.pypa.io/ez_setup.py").read(), ez)
 
 if not options.allow_site_packages:
     # ez_setup imports site, which adds site packages
     # this will remove them from the path to ensure that incompatible versions
     # of setuptools are not in the path
     import site
+
     # inside a virtualenv, there is no 'getsitepackages'.
     # We can't remove these reliably
-    if hasattr(site, 'getsitepackages'):
+    if hasattr(site, "getsitepackages"):
         for sitepackage_path in site.getsitepackages():
             sys.path[:] = [x for x in sys.path if sitepackage_path not in x]
 
-setup_args = {'to_dir': tmpeggs, 'download_delay': 0}
-ez['use_setuptools'](**setup_args)
+setup_args = {"to_dir": tmpeggs, "download_delay": 0}
+ez["use_setuptools"](**setup_args)
 import setuptools
 import pkg_resources
 
@@ -104,36 +117,43 @@ for path in sys.path:
 
 ws = pkg_resources.working_set
 
-cmd = [sys.executable, '-c',
-       'from setuptools.command.easy_install import main; main()',
-       '-mZqNxd', tmpeggs]
+cmd = [
+    sys.executable,
+    "-c",
+    "from setuptools.command.easy_install import main; main()",
+    "-mZqNxd",
+    tmpeggs,
+]
 
 find_links = os.environ.get(
-    'bootstrap-testing-find-links',
-    options.find_links or
-    ('https://downloads.buildout.org/'
-     if options.accept_buildout_test_releases else None)
-    )
+    "bootstrap-testing-find-links",
+    options.find_links
+    or (
+        "https://downloads.buildout.org/"
+        if options.accept_buildout_test_releases
+        else None
+    ),
+)
 if find_links:
-    cmd.extend(['-f', find_links])
+    cmd.extend(["-f", find_links])
 
-setuptools_path = ws.find(
-    pkg_resources.Requirement.parse('setuptools')).location
+setuptools_path = ws.find(pkg_resources.Requirement.parse("setuptools")).location
 
-requirement = 'zc.buildout'
+requirement = "zc.buildout"
 version = options.version
 if version is None and not options.accept_buildout_test_releases:
     # Figure out the most recent final version of zc.buildout.
     import setuptools.package_index
-    _final_parts = '*final-', '*final'
+
+    _final_parts = "*final-", "*final"
 
     def _final_version(parsed_version):
         for part in parsed_version:
-            if (part[:1] == '*') and (part not in _final_parts):
+            if (part.startswith("*")) and (part not in _final_parts):
                 return False
         return True
-    index = setuptools.package_index.PackageIndex(
-        search_path=[setuptools_path])
+
+    index = setuptools.package_index.PackageIndex(search_path=[setuptools_path])
     if find_links:
         index.add_find_links((find_links,))
     req = pkg_resources.Requirement.parse(requirement)
@@ -152,13 +172,13 @@ if version is None and not options.accept_buildout_test_releases:
             best.sort()
             version = best[-1].version
 if version:
-    requirement = '=='.join((requirement, version))
+    requirement = "==".join((requirement, version))
 cmd.append(requirement)
 
 import subprocess
+
 if subprocess.call(cmd, env=dict(os.environ, PYTHONPATH=setuptools_path)) != 0:
-    raise Exception(
-        "Failed to execute command:\n%s" % repr(cmd)[1:-1])
+    raise Exception("Failed to execute command:\n%s" % repr(cmd)[1:-1])
 
 ######################################################################
 # Import and run buildout
@@ -167,12 +187,12 @@ ws.add_entry(tmpeggs)
 ws.require(requirement)
 import zc.buildout.buildout
 
-if not [a for a in args if '=' not in a]:
-    args.append('bootstrap')
+if not [a for a in args if "=" not in a]:
+    args.append("bootstrap")
 
 # if -c was provided, we push it back into args for buildout' main function
 if options.config_file is not None:
-    args[0:0] = ['-c', options.config_file]
+    args[0:0] = ["-c", options.config_file]
 
 zc.buildout.buildout.main(args)
 shutil.rmtree(tmpeggs)
